<?php
/**
 * 豆勒个瓣
 * 
 * @package DouLeGeBan 
 * @author 冰剑
 * @version 1.0.0
 * @link http://www.binjoo.net
 */
class DouLeGeBan_Plugin implements Typecho_Plugin_Interface
{
    /**
     * 激活插件方法,如果激活失败,直接抛出异常
     * 
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
    public static function activate()
    {
        return '此插件激活后，必须设置豆瓣帐户才能正常使用。';
    }
    
    /**
     * 禁用插件方法,如果禁用失败,直接抛出异常
     * 
     * @static
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
    public static function deactivate(){}
    
    /**
     * 获取插件配置面板
     * 
     * @access public
     * @param Typecho_Widget_Helper_Form $form 配置面板
     * @return void
     */
    public static function config(Typecho_Widget_Helper_Form $form)
    {
        /** 豆瓣账户 **/
        $username = new Typecho_Widget_Helper_Form_Element_Text('username', NULL, NULL, _t('豆瓣帐户'), '<span style="color:red">必填</span> 你的豆瓣帐户，一般为豆瓣个人主页地址 http://www.douban.com/plepeo/<b>binjoo</b> 中的粗体。');
        $username->input->setAttribute('class', 'mini');
        $form->addInput($username);
        /** 通用显示数量 **/
        $apikey = new Typecho_Widget_Helper_Form_Element_Text('apikey', NULL, NULL, _t('API Key'), '不使用API Key时每分钟请求不能超过10次；使用API Key时，对访问的限制较为宽松，为每分钟40次。<br /><span style="color:red">请注意：如果没有API Key请保持为空，胡乱填写会导致读取不到豆瓣数据。</span>');
        $form->addInput($apikey);
        $docs = new Typecho_Widget_Helper_Form_Element_Text('docs', NULL, NULL, _t('功能介绍'), '目前本插件仅支持调用相关用户的电影、读书、音乐三个模块的信息。');
        $docs->input->setAttribute('style', 'display:none');
        $form->addInput($docs);
    }
    
    /**
     * 个人用户的配置面板
     * 
     * @access public
     * @param Typecho_Widget_Helper_Form $form
     * @return void
     */
    public static function personalConfig(Typecho_Widget_Helper_Form $form){}

    /**
     * 字符串参数转化为数组形式
     *
     * $args 字符串参数
     * $defaults 默认数组
     */
    public static function parse_args($args, $defaults)
    {
        parse_str($args, $args);//把字符串参数转换成数组
        if(is_array($defaults)){
            return array_merge($defaults, $args);//将args中的键值覆盖到defaults
        }
        return $defaults;
    }
    /**
     * 豆瓣电影
     * 
     * @access public
     * @return void
     */
    public static function showMovie($args=null)
    {
        echo self::getDBData('movie', $args);
    }    
    /**
     * 豆瓣音乐
     * 
     * @access public
     * @return void
     */
    public static function showMusic($args=null)
    {
        echo self::getDBData('music', $args);
    }    
    /**
     * 豆瓣读书
     * 
     * @access public
     * @return void
     */
    public static function showBook($args=null)
    {
        echo self::getDBData('book', $args);
    }  
    /**
     * 获得豆瓣数据
     * 
     * @access public
     * @return void
     */
    public static function getDBData($type, $args)
    {
        $defaults = array(
            'number' => 50,
            'xformat' => '<a title="{title}" href="{url}"><img src="{img}" /></a>'
        );
        if($args != null){
            $defaults = self::parse_args($args, $defaults);
        }
        $settings = Helper::options()->plugin('DouLeGeBan');
        $username = $settings->username;
        $apikey = $settings->apikey;
        $url = "http://api.douban.com/people/".$username."/collection?cat=".$type."&alt=json&max-results=".$defaults['number'];
        if($apikey != null){
            $url .= '&apikey='.$apikey;
        }
        $result = "";
        $r = @file_get_contents($url);
        if(!$r){
            return "豆勒个瓣出现异常，请检查设置是否正确！";
        }
        $data = json_decode($r, true);
        $entry = $data['entry'];
        $num = count($entry);
        for ($i = 0; $i < $num; $i++ )
        {
            $title = $entry[$i]['db:subject']['title']['$t'];//标题
            $url = $entry[$i]['db:subject']['link'][1]['@href'];//地址
            $img = $entry[$i]['db:subject']['link'][2]['@href'];//图片
            $result .= str_replace(array('{title}', '{url}', '{img}'), array($title, $url, $img), $defaults['xformat']);
        }
        return $result;
    }
}
